import { state } from "./utils/state";

export async function getGrokAuthedCookies() {
	if (!process.env.FLARESOLVERR_BASE_URL)
		throw new Error("No flaresolverr found");

	const req = await fetch(
		`${process.env.FLARESOLVERR_BASE_URL!.replace(/\/(v1)?$/, "")}/v1`,
		{
			method: "POST",
			headers: {
				"Content-Type": "application/json"
			},
			body: JSON.stringify({
				cmd: "request.get",
				url: "https://grok.com/",
				maxTimeout: 60000
			})
		}
	);

	if (!req.ok) throw new Error(await req.text());
	const data = await req.json();
	if (data.status !== "ok") {
		console.error(data);
		throw new Error(data);
	}

	const {
		solution: { userAgent, cookies }
	} = data;

	state.grokMeta = {
		userAgent,
		cookies: (cookies as any[]).reduce((acc, { name, value }) => {
			acc[name] = value;
			return acc;
		}, {}),
		expiresIn: {
			time: Date.now() + 60 * 60 * 1000,
			requests: 3
		}
	};
}
